@@ -65,6 +65,10 @@ class Subform(object):
         kwargs.update(self.kwargs)
         return self.formclass(*formargs, **kwargs)
 
+    @property
+    def prefix(self):
+        return self.kwargs['prefix']
+
 
 class CombinedFormMetaclass(type):
     """Allow a declarative style of CombinedForm generation."""
@@ -162,7 +166,8 @@ def add_error(form, error):
         if field not in form.errors:
             if field not in form.fields:
                 raise ValueError(
-                    "'%s' has no field named '%s'." % (form.__class__.__name__, field))
+                    "'%s' has no field named '%s'." % (form.__class__.__name__,
+                                                       field))
             form._errors[field] = form.error_class()
         form._errors[field].extend(error_list)
         if field in form.cleaned_data:
@@ -305,6 +310,7 @@ class CombinedForm(object, metaclass=CombinedFormMetaclass):
     def __unicode__(self):
         """Show all subforms with markup."""
         return self.as_p()
+
     def as_p(self):
         """Return all subforms as_p combined."""
         all_forms = ''.join(form.as_p() for form in list(self.values()))
@@ -348,6 +354,33 @@ class CombinedForm(object, metaclass=CombinedFormMetaclass):
                 return False
         return True
 
+    @property
+    def cleaned_data(self):
+        """Get a dictionary of cleaned values from all subforms.
+
+        Values get prefixed with the subform's prefix and a '-'. This is
+        different than a standard Django form, which returns all values
+        without any prefixes.
+
+        Raises an exception if the formset is not valid.
+
+        """
+        combined_data = {}
+        for subform_name in self:
+
+            # cleaned data from subforms come back without any prefix, so
+            # manually reattach
+            subform_data = self[subform_name].cleaned_data
+            subform_prefix = getattr(type(self), subform_name).prefix
+
+            def prefixed(s):
+                return subform_prefix + "-" + s
+
+            prefixed_data = {prefixed(k): v for k, v in subform_data.items()}
+            combined_data.update(prefixed_data)
+
+        return combined_data
+
     @property
     def non_field_errors(self):
         """Get all non-field errors on all subforms and the CombinedForm.
@@ -524,7 +557,10 @@ def order_by_dependency(models):
         def __unicode__(self):
             mname = self.model.__name__
             dstr = ", ".join(d.model.__name__ for d in self.dependents)
-            if not dstr: dstr = '[]'
+
+            if not dstr:
+                dstr = '[]'
+
             return "Node(model={}, dependents={})".format(mname, dstr)
 
         def __str__(self):
@@ -538,6 +574,7 @@ def order_by_dependency(models):
         return (f for f in m._meta.fields if isinstance(f, ForeignKey))
 
     nodemap = {}
+
     def get_nodemap(key):
         """Get value at key, or if it doesn't exist create an empty Node."""
         val = nodemap.get(key, Node(key))
